"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_table_1 = require("@tanstack/react-table");
require("./TableBody.scss");
const styleUtils_1 = require("../utils/styleUtils");
const sortable_1 = require("@dnd-kit/sortable");
const utilities_1 = require("@dnd-kit/utilities");
const react_1 = __importDefault(require("react"));
function TableBody({ table, tableOptions, columnOrder, featureOptions, }) {
    const { currentPadding } = tableOptions;
    const { enableColumnReording } = featureOptions;
    return (react_1.default.createElement("tbody", { className: "ts__body" }, table.getRowModel().rows.map((row) => (react_1.default.createElement("tr", { className: "ts__body__tr", key: row.id }, row.getVisibleCells().map((cell) => {
        var _a, _b;
        return !enableColumnReording ? (react_1.default.createElement("td", { key: cell.id,
            style: Object.assign(Object.assign({}, (0, styleUtils_1.getColumnPinningStylesBody)(cell.column)), { width: cell.column.getSize(), padding: `${currentPadding}` }),
            align: ((_a = cell.column.columnDef.meta) === null || _a === void 0 ? void 0 : _a.align) || "left",
            className: "ts__body__td" }, cell.getIsGrouped() ? (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement("button", { onClick: row.getToggleExpandedHandler() },
                (0, react_table_1.flexRender)(cell.column.columnDef.cell, cell.getContext()),
                " ",
                "(",
                row.subRows.length,
                ")"))) : cell.getIsAggregated() ? ((0, react_table_1.flexRender)((_b = cell.column.columnDef.aggregatedCell) !== null && _b !== void 0 ? _b : cell.column.columnDef.cell, cell.getContext())) : cell.getIsPlaceholder() ? null : ((0, react_table_1.flexRender)(cell.column.columnDef.cell, cell.getContext())))) : (react_1.default.createElement(sortable_1.SortableContext, { key: cell.id, items: columnOrder, strategy: sortable_1.horizontalListSortingStrategy },
            react_1.default.createElement(DragAlongCell, { key: cell.id, cell: cell, row: row, tableOptions: tableOptions })));
    }))))));
}
exports.default = TableBody;
function DragAlongCell({ cell, row, tableOptions, }) {
    var _a, _b;
    const { isDragging, setNodeRef, transform } = (0, sortable_1.useSortable)({
        id: cell.column.id,
    });
    const { currentPadding } = tableOptions;
    const style = {
        opacity: isDragging ? 0.6 : 1,
        position: "relative",
        transform: utilities_1.CSS.Translate.toString(transform),
        transition: "width transform 0.2s ease-in-out",
        width: cell.column.getSize(),
        zIndex: isDragging ? 1 : 0,
        padding: `${currentPadding}`,
    };
    return (react_1.default.createElement("td", { ref: setNodeRef, style: Object.assign(Object.assign({}, style), (0, styleUtils_1.getColumnPinningStylesBody)(cell.column)),
        align: ((_a = cell.column.columnDef.meta) === null || _a === void 0 ? void 0 : _a.align) || "left",
        className: "ts__body__td" }, cell.getIsGrouped() ? (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("button", { onClick: row.getToggleExpandedHandler() },
            (0, react_table_1.flexRender)(cell.column.columnDef.cell, cell.getContext()),
            " (",
            row.subRows.length,
            ")"))) : cell.getIsAggregated() ? ((0, react_table_1.flexRender)((_b = cell.column.columnDef.aggregatedCell) !== null && _b !== void 0 ? _b : cell.column.columnDef.cell, cell.getContext())) : cell.getIsPlaceholder() ? null : ((0, react_table_1.flexRender)(cell.column.columnDef.cell, cell.getContext()))));
}
