"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Filter = void 0;
const react_table_1 = require("@tanstack/react-table");
require("./TableHead.scss");
const svg_1 = require("../assets/svg");
const DropdownMenu_1 = __importDefault(require("./DropdownMenu"));
const sortable_1 = require("@dnd-kit/sortable");
const styleUtils_1 = require("../utils/styleUtils");
const Topbar_1 = require("./Topbar");
const utilities_1 = require("@dnd-kit/utilities");
const react_1 = __importDefault(require("react"));
function TableHead({ table, tableOptions, columnOrder, featureOptions, }) {
    const { enableColumnReording } = featureOptions;
    return (react_1.default.createElement("thead", { className: "ts__head" }, table.getHeaderGroups().map((headerGroup) => (react_1.default.createElement("tr", { className: "ts__head__tr", key: headerGroup.id }, enableColumnReording ? (react_1.default.createElement(sortable_1.SortableContext, { items: columnOrder, strategy: sortable_1.horizontalListSortingStrategy }, headerGroup.headers.map((header) => (react_1.default.createElement(DraggableTableHeader, { key: header.id, header: header, featureOptions: featureOptions, tableOptions: tableOptions }))))) : (headerGroup.headers.map((header) => {
        var _a;
        return (react_1.default.createElement("th", { className: `ts__head__th ${header.isPlaceholder ? "" : "ts__border"}`, key: header.id, style: Object.assign(Object.assign({}, (0, styleUtils_1.getColumnPinningStyles)(header.column)), { width: `${header.column.getSize()}px `, minWidth: `${header.column.columnDef.minSize}px`, maxWidth: `${header.column.columnDef.maxSize}px` }), colSpan: header.colSpan, align: ((_a = header.column.columnDef.meta) === null || _a === void 0 ? void 0 : _a.align) || "left" },
            react_1.default.createElement(TableHeadContent, { featureOptions: featureOptions, header: header, tableOptions: tableOptions })));
    })))))));
}
exports.default = TableHead;
function DraggableTableHeader({ header, featureOptions, tableOptions, }) {
    var _a, _b;
    const { isDragging, setNodeRef, transform } = (0, sortable_1.useSortable)({
        id: header.column.id,
    });
    const style = {
        opacity: isDragging ? 0.6 : 1,
        transform: utilities_1.CSS.Translate.toString(transform),
        transition: "width transform 0.2s ease-in-out",
        minWidth: `${(_a = header.column.columnDef.minSize) !== null && _a !== void 0 ? _a : 180}px`,
        maxWidth: `${header.column.columnDef.maxSize}px`,
        zIndex: isDragging ? 1 : 0,
        padding: `${tableOptions.currentPadding}`,
    };
    return (react_1.default.createElement("th", { ref: setNodeRef, className: `ts__head__th ${header.isPlaceholder ? "" : "ts__border"}`, key: header.id, style: Object.assign(Object.assign({}, (0, styleUtils_1.getColumnPinningStyles)(header.column)), style), colSpan: header.colSpan, align: ((_b = header.column.columnDef.meta) === null || _b === void 0 ? void 0 : _b.align) || "left" },
        react_1.default.createElement(TableHeadContent, { header: header, featureOptions: featureOptions, tableOptions: tableOptions })));
}
function Filter({ column }) {
    const columnFilterValue = column.getFilterValue();
    return (react_1.default.createElement("div", null,
        react_1.default.createElement(Topbar_1.DebouncedInput, { type: "text", value: (columnFilterValue !== null && columnFilterValue !== void 0 ? columnFilterValue : ""), onChange: (value) => column.setFilterValue(value), placeholder: `search by ${column.columnDef.header}` })));
}
exports.Filter = Filter;
function TableHeadContent({ header, featureOptions, tableOptions, }) {
    var _a, _b;
    const { enableSorting, enableVerticalDots, enableColumnReording } = featureOptions;
    const { isDropdownOpen, setIsDropdownOpen, openFilter } = tableOptions;
    const { attributes, listeners } = (0, sortable_1.useSortable)({
        id: header.column.id,
    });
    const handleDropdownClickForColumn = (id) => {
        if (isDropdownOpen === id) {
            setIsDropdownOpen("");
        }
        else {
            setIsDropdownOpen(id);
        }
    };
    const alignment = (_a = header.column.columnDef.meta) === null || _a === void 0 ? void 0 : _a.align;
    const justifyContentStyle = (0, styleUtils_1.getColumnJustifyContent)(alignment);
    console.log(header.column.getCanGroup());
    return (react_1.default.createElement(react_1.default.Fragment, null,
        isDropdownOpen === header.id && enableVerticalDots && (react_1.default.createElement(DropdownMenu_1.default, { top: 50, right: 16 },
            !header.isPlaceholder &&
                header.column.getCanSort() &&
                enableSorting && (react_1.default.createElement("div", { className: "ts__head__dropdown__group" },
                react_1.default.createElement("button", { disabled: header.column.getIsSorted() === false, onClick: () => {
                        header.column.clearSorting();
                        handleDropdownClickForColumn(header.id);
                    } }, "Clear Sort"),
                react_1.default.createElement("button", { disabled: header.column.getIsSorted() === "asc", onClick: () => {
                        header.column.toggleSorting();
                        handleDropdownClickForColumn(header.id);
                    } }, "Sort ascending"),
                react_1.default.createElement("button", { disabled: header.column.getIsSorted() === "desc", onClick: () => {
                        header.column.toggleSorting();
                        handleDropdownClickForColumn(header.id);
                    } }, "Sort descending"))),
            header.column.getCanSort() && react_1.default.createElement("div", { className: "divider" }),
            !header.isPlaceholder && header.column.getCanPin() && (react_1.default.createElement("div", { className: "ts__head__dropdown__group" },
                react_1.default.createElement("button", { disabled: header.column.getIsPinned() === "left", onClick: () => {
                        header.column.pin("left");
                        handleDropdownClickForColumn(header.id);
                    } }, "Pin to left"),
                react_1.default.createElement("button", { disabled: header.column.getIsPinned() === "right", onClick: () => {
                        header.column.pin("right");
                        handleDropdownClickForColumn(header.id);
                    } }, "Pin to Right"),
                react_1.default.createElement("button", { disabled: header.column.getIsPinned() === false, onClick: () => {
                        header.column.pin(false);
                        handleDropdownClickForColumn(header.id);
                    } }, "Unpin"))),
            header.column.getCanPin() && react_1.default.createElement("div", { className: "divider" }),
            !header.isPlaceholder && header.column.getCanGroup() && (react_1.default.createElement("div", { className: "ts__head__dropdown__group" },
                react_1.default.createElement("button", { onClick: () => {
                        header.column.toggleGrouping();
                        handleDropdownClickForColumn(header.id);
                    } }, header.column.getIsGrouped()
                    ? `Ungroup by ${header.column.columnDef.header}`
                    : `Group by ${header.column.columnDef.header}`))))),
        header.isPlaceholder ? null : (react_1.default.createElement("div", null,
            react_1.default.createElement("div", { className: "ts__head__th__container", style: { justifyContent: justifyContentStyle } },
                react_1.default.createElement("span", { onClick: enableSorting
                        ? header.column.getToggleSortingHandler()
                        : () => { } },
                    react_1.default.createElement(react_1.default.Fragment, null,
                        (0, react_table_1.flexRender)(header.column.columnDef.header, header.getContext()),
                        " ", (_b = { asc: react_1.default.createElement(svg_1.UpArrow, null), desc: react_1.default.createElement(svg_1.DownArrow, null) }[header.column.getIsSorted()]) !== null && _b !== void 0 ? _b : react_1.default.createElement(react_1.default.Fragment, null, enableSorting ? react_1.default.createElement(svg_1.ArrowDownUp, null) : null))),
                enableColumnReording && (react_1.default.createElement("div", Object.assign({}, attributes, listeners, { className: "ts__dnd__button" }),
                    react_1.default.createElement(svg_1.DragHandleIcon, null))),
                header.subHeaders.length == 0
                    ? enableVerticalDots && (react_1.default.createElement("div", { onClick: () => handleDropdownClickForColumn(header.id) },
                        " ",
                        react_1.default.createElement(svg_1.VerticalThreeDots, null)))
                    : null),
            openFilter && header.subHeaders.length == 0 ? (header.column.getCanFilter() ? (react_1.default.createElement("div", { className: "ts__head__th__filter" },
                react_1.default.createElement(Filter, { column: header.column }))) : null) : null)),
        header.column.getCanResize() ? (react_1.default.createElement("div", { onDoubleClick: () => header.column.resetSize(), onMouseDown: header.getResizeHandler(), onTouchStart: header.getResizeHandler(), className: `column__resize ${header.column.getIsResizing() ? "is__resizing" : ""}` })) : null));
}
