"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
require("./dist/TableWrapper.scss");
const TableHead_1 = __importDefault(require("./TableHead"));
const TableBody_1 = __importDefault(require("./TableBody"));
const Topbar_1 = __importDefault(require("./Topbar"));
const core_1 = require("@dnd-kit/core");
const sortable_1 = require("@dnd-kit/sortable");
const modifiers_1 = require("@dnd-kit/modifiers");
const react_1 = require("react");
const react_table_1 = require("@tanstack/react-table");
const Pagination_1 = __importDefault(require("./Pagination"));
const react_2 = __importDefault(require("react"));
function TableWrapper({ style, tableOptions, data, column, paginationTotalRows, featureOptions, }) {
    const { sorting, columnVisibility, globalFilter, grouping, pagination, setColumnVisibility, setSorting, setGlobalFilter, setGrouping, setPagination, rowSelection, setRowSelection, } = tableOptions;
    const featureOptionsDefault = Object.assign({ enableColumnResizing: true, enableSorting: true, enableFilter: true, enableTopbar: true, enableGlobalFilter: true, enableSearch: true, enableColumnPadding: true, enableColumnReording: true, enableColumnHiding: true, enableVerticalDots: true, enableColumnGrouping: false, enableColumnPinning: true, enableServerSidePagination: true }, featureOptions);
    const { enableFilter, enableGlobalFilter, enableColumnHiding, enableSorting, enableColumnResizing, enableColumnPinning, enableServerSidePagination, enableTopbar, enableColumnReording, } = featureOptionsDefault;
    const [columns] = (0, react_1.useState)(() => [...column]);
    const [columnOrder, setColumnOrder] = (0, react_1.useState)(() => columns.map((c) => c.id));
    const table = (0, react_table_1.useReactTable)({
        columns,
        data,
        state: {
            columnOrder,
            sorting,
            columnVisibility,
            globalFilter,
            grouping,
            pagination,
            rowSelection,
        },
        getCoreRowModel: (0, react_table_1.getCoreRowModel)(),
        getSortedRowModel: (0, react_table_1.getSortedRowModel)(),
        getFilteredRowModel: (0, react_table_1.getFilteredRowModel)(),
        getGroupedRowModel: (0, react_table_1.getGroupedRowModel)(),
        getExpandedRowModel: (0, react_table_1.getExpandedRowModel)(),
        onColumnVisibilityChange: setColumnVisibility,
        onSortingChange: setSorting,
        onGlobalFilterChange: setGlobalFilter,
        onGroupingChange: setGrouping,
        onRowSelectionChange: setRowSelection,
        enableColumnFilters: enableFilter,
        enableGlobalFilter: enableGlobalFilter,
        enableHiding: enableColumnHiding,
        enableSorting: enableSorting,
        enableGrouping: false,
        enableColumnResizing: enableColumnResizing,
        enableColumnPinning: enableColumnPinning,
        columnResizeDirection: "ltr",
        columnResizeMode: "onChange",
        getFacetedMinMaxValues: (0, react_table_1.getFacetedMinMaxValues)(),
        onPaginationChange: setPagination,
        manualPagination: enableServerSidePagination,
        pageCount: Math.floor(paginationTotalRows / pagination.pageSize) + 1,
        debugTable: true,
        debugHeaders: true,
        debugColumns: true,
    });
    function handleDragEnd(event) {
        const { active, over } = event;
        if (active && over && active.id !== over.id) {
            setColumnOrder((columnOrder) => {
                const oldIndex = columnOrder.indexOf(active.id);
                const newIndex = columnOrder.indexOf(over.id);
                return (0, sortable_1.arrayMove)(columnOrder, oldIndex, newIndex); //this is just a splice util
            });
        }
    }
    const sensors = (0, core_1.useSensors)((0, core_1.useSensor)(core_1.MouseSensor, {}), (0, core_1.useSensor)(core_1.TouchSensor, {}), (0, core_1.useSensor)(core_1.KeyboardSensor, {}));
    return (react_2.default.createElement(react_2.default.Fragment, null,
        enableTopbar && (react_2.default.createElement(Topbar_1.default, { data: data, tableOptions: tableOptions, table: table, featuresOptions: featureOptionsDefault })),
        react_2.default.createElement("div", { className: "ts__table__wrapper" }, enableColumnReording ? (react_2.default.createElement(core_1.DndContext, { collisionDetection: core_1.closestCenter, modifiers: [modifiers_1.restrictToHorizontalAxis], onDragEnd: handleDragEnd, sensors: sensors },
            react_2.default.createElement("table", { className: `ts__table ${style}` },
                react_2.default.createElement(TableHead_1.default, { table: table, featureOptions: featureOptionsDefault, tableOptions: tableOptions, columnOrder: columnOrder }),
                react_2.default.createElement(TableBody_1.default, { table: table, tableOptions: tableOptions, columnOrder: columnOrder, featureOptions: featureOptionsDefault })))) : (react_2.default.createElement("table", { className: `ts__table ${style}` },
            react_2.default.createElement(TableHead_1.default, { table: table, featureOptions: featureOptionsDefault, tableOptions: tableOptions, columnOrder: columnOrder }),
            react_2.default.createElement(TableBody_1.default, { table: table, tableOptions: tableOptions, columnOrder: columnOrder, featureOptions: featureOptionsDefault })))),
        react_2.default.createElement(Pagination_1.default, { table: table })));
}
exports.default = TableWrapper;
